[dests] Fix hipTestClock, hipTestNew & hipTestGlobalVariable tests for nvcc

nvcc does not support global kernels in struct/class

Change-Id: I2d7297e0c3725564215e20dbdd31c0bb8d7a07de


[ROCm/hip commit: cca2c5afc8]
Tento commit je obsažen v:
Maneesh Gupta
2018-09-17 15:32:05 +05:30
rodič e14fc1c65e
revize 5947c0e94d
3 změnil soubory, kde provedl 8 přidání a 19 odebrání
+1 -4
Zobrazit soubor
@@ -33,8 +33,6 @@ THE SOFTWARE.
#define LEN 512
#define SIZE 2048
struct TestClock {
static __global__ void kernel1(int* Ad) {
int tid = threadIdx.x + blockIdx.x * blockDim.x;
Ad[tid] = clock() + clock64() + __clock() + __clock64();
@@ -61,9 +59,8 @@ struct TestClock {
assert(0 != A[i]);
}
}
};
int main() {
TestClock().run();
run();
passed();
}
+1 -3
Zobrazit soubor
@@ -33,7 +33,6 @@ THE SOFTWARE.
#define LEN 512
#define SIZE 2048
struct TestPlacementNew {
class A {
public:
__device__ A() {
@@ -63,9 +62,8 @@ struct TestPlacementNew {
assert(i == A[i]);
}
}
};
int main() {
TestPlacementNew().run();
run();
passed();
}